import * as shared from '@volar/shared';
import * as SourceMap from '@volar/source-map';
import type * as html from 'vscode-html-languageservice';
import { TextDocument } from 'vscode-languageserver-textdocument';
export interface PugDocument extends ReturnType<typeof parsePugDocument> {
}
export declare function parsePugDocument(pugTextDoc: TextDocument, htmlLs: html.LanguageService): {
    pugTextDocument: shared.TextDocument;
    htmlTextDocument: shared.TextDocument;
    htmlDocument: shared.HTMLDocument;
    pugCode: string;
    htmlCode: string;
    sourceMap: SourceMap.SourceMap<{
        isEmptyTagCompletion: boolean;
    } | undefined>;
    error: {
        code: string;
        msg: string;
        line: number;
        column: number;
        filename: string;
    } | undefined;
    ast: Node | undefined;
};
export declare type Node = BlockNode | TagNode | TextNode | CommentNode | BlockCommentNode;
export interface BlockNode {
    type: 'Block';
    nodes: Node[];
    line: number;
}
export interface TagNode {
    type: 'Tag';
    name: string;
    selfClosing: boolean;
    block: BlockNode;
    attrs: {
        name: string;
        val: string | true;
        line: number;
        column: number;
        mustEscape: boolean;
    }[];
    attributeBlocks: {}[];
    isInline: boolean;
    line: number;
    column: number;
}
export interface TextNode {
    type: 'Text';
    val: string;
    line: number;
    column: number;
}
export interface CommentNode {
    type: 'Comment';
    val: string;
    buffer: boolean;
    line: number;
    column: number;
}
export interface BlockCommentNode {
    type: 'BlockComment';
    block: BlockNode;
    val: string;
    buffer: boolean;
    line: number;
    column: number;
}
